@@ -3,9 +3,13 @@
 # Eric Hameleers <alien@slackware.com> (encryption support)
 
 LIVELABEL="LIVE" #edit in init script too
-#SLACKEL_FLAVOR="Slackel-kde-4.14.21"
-SLACKEL_FLAVOR="Slackel-openbox-7.1"
-SLACKEL_FLAVOR_LILO="Slackel-openbox"
+#SLACKEL_FLAVOR="Slackel-kde-7.7.0"
+#SLACKEL_FLAVOR_LILO="Slackel-kde"
+#SLACKEL_FLAVOR="Slackel-openbox-7.7.0"
+#SLACKEL_FLAVOR_LILO="Slackel-openbox"
+SLACKEL_FLAVOR="Slackel-mate-7.7.0"
+SLACKEL_FLAVOR_LILO="Slackel-mate"
+
 #LIVEFSOPTS="-O ^has_journal"
 
 CMDERROR=1
@@ -151,7 +155,7 @@ EOF
 #EOF
 #		fi
 		#dd if=/dev/zero of=/tmp/efi.img bs=1k count=32768
-		dd if=/dev/zero of=/tmp/efi.img bs=1M count=20
+		dd if=/dev/zero of=/tmp/efi.img bs=1M count=30
 		mkdosfs -n "EFIBOOT" /tmp/efi.img
 		mount -o loop /tmp/efi.img /mnt/floppy
 		cp -dpR $livedirectory/EFI /mnt/floppy/
@@ -506,6 +510,8 @@ function install_system() {
 	format_home=$9
 	SYSINSTALLFS=${10}
 	home_dir=${11}
+	locale=${12}
+	keyboard=${13}
 	
 	#SYSINSTALLFS="ext4" # set default filesystem of root
 	if [ "$SYSINSTALLFS" == "" ]; then
@@ -604,7 +610,7 @@ function install_system() {
 	
 	mkdir -p /mnt/install/{dev,proc,sys,tmp}
 	cp -dpr /dev/sd* /mnt/install/dev/ #create disk nodes needed for LiLo
-	for dir in sys proc dev; do mount --bind /$dir /mnt/install/$dir; done
+	for dir in sys proc dev tmp; do mount --bind /$dir /mnt/install/$dir; done
 	#if [ "$rootdirectory" = "/live/modules" ]; then
 	#	cp -dpr /live/system/lib/udev/devices/* /mnt/install/dev/
 	#fi
@@ -623,14 +629,29 @@ function install_system() {
 	if [ -f /etc/X11/xorg.conf ]; then
 		cp -f /etc/X11/xorg.conf /mnt/install/etc/X11/
 	fi
+	
+	# set clock
+	if [ -x /etc/rc.d/rc.ntpd ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.ntpd
+		cp -f /etc/ntp.conf /mnt/install/etc/
+	fi
+
 	if [ -f /etc/localtime ] &&  [ -h /etc/localtime-copied-from  ]; then
-		cp -f /etc/localtime /mnt/install/etc/
-		cp -df /etc/localtime-copied-from /mnt/install/etc/
+		cp -df /etc/localtime /mnt/install/etc/localtime
+		cp -df /etc/localtime-copied-from /mnt/install/etc/localtime-copied-from
 	fi
 	if [ -f /etc/hardwareclock ]; then
 		cp -f /etc/hardwareclock /mnt/install/etc/
 	fi
 	#Copy end
+	#################
+	ROOTPART=$(lsblk -l -o name,mountpoint| grep /mnt/install$|sed "s,\([^[:space:]]*\).*,/dev/\1,")
+	ROOTNAME=$(echo $ROOTPART|sed "s,/dev/,,")
+	ROOTUUID=$(lsblk -l -o name,uuid|grep ^$ROOTNAME|sed "s/[^ ]*[[:space:]]*//")
+	#FSTYPE=$(lsblk -l -o name,fstype|grep ^$ROOTNAME|sed "s/[^ ]*[[:space:]]*//")
+	#ROOTDEVICE=/dev/$(lsblk -l -o name,pkname|grep ^$ROOTNAME|sed "s/[^ ]*[[:space:]]*//")
+	#BRAND=$(grep ^NAME /mnt/etc/os-release|sed "s/.*=//")
+	#################
 	echo "Setting up fstab"
 	#FSTab begin
 	cat > /mnt/install/etc/fstab << EOF
@@ -701,7 +722,8 @@ EOF
 	#InitRD begin
 	if [ ! -f /mnt/install/boot/initrd.gz ]; then
 		echo "Setting initrd"
-		kv=`basename /mnt/install/lib/modules/*`
+		#kv=`basename /mnt/install/lib/modules/*`
+		kv=`ls -l /mnt/install/boot/vmlinuz | cut -f2 -d'>' | sed s/^[^0-9]*//`
 		if lsmod | grep -q $SYSINSTALLFS; then
 			moduleslist="$SYSINSTALLFS"
 		fi
@@ -723,6 +745,22 @@ EOF
 			#chroot /mnt/install umount /proc
 		fi
 	fi
+		
+	#####
+     installdevice=`echo $systempart | cut -c1-8`
+     if [ "$installdevice" != "/dev/sda" ]; then 
+		#if [ -f /live/media/boot/initrd-usb.gz ]; then 
+			echo "Copying initrd"
+			#kv=`basename /mnt/install/lib/modules/*`
+			kv=`ls -l /mnt/install/boot/vmlinuz | cut -f2 -d'>' | sed s/^[^0-9]*//`
+			#MODULES="loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:mmc-core:mmc-block:sdhci:sdhci-pci:sdhci-acpi:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-apple:hid-asus:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:crc32c-intel:fuse"
+			MODULES="loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:mmc-core:mmc-block:sdhci:sdhci-pci:sdhci-acpi:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-apple:hid-asus:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:crc32c-intel:fuse:nls_cp437:nls_iso8859-1"
+			chroot /mnt/install mkinitrd -c -f $SYSINSTALLFS -u -w 10 -o /boot/initrd.gz -r UUID=$ROOTUUID -k $kv -m $MODULES
+			chroot /mnt/install rm -rf /boot/initrd-tree/
+			#cp /live/media/boot/initrd-usb.gz /mnt/install/boot/initrd.gz
+		#fi	
+     fi
+     #####
 	#InitRD end
    if [ "$bootloader" == "lilo" ]; then
 	#LiLo begin
@@ -730,7 +768,12 @@ EOF
 		installdevice=`echo $systempart | cut -c1-8`
 		echo "Setting (e)Lilo"
 		if [ -d /sys/firmware/efi ]; then #UEFI
-			modprobe efivars
+			if [ "$(/bin/ls /sys/firmware/efi/efivars 2> /dev/null | wc -l)" = "0" ]; then
+				echo "Make sure efivarfs is active since we'll need it to"
+				echo "mount efivars"
+				modprobe efivarfs
+				mount -t efivarfs efivarfs /sys/firmware/efi/efivars
+			fi	
 			efipartnum=`gdisk -l $installdevice | grep "EF00" | sed 's/  \+/ /g' | cut -f2 -d' '`
 			efipartition="$installdevice$efipartnum"
 			if [ ! -z "$efipartition" ]; then
@@ -757,14 +800,56 @@ image=vmlinuz
     append="root=$systempart ro"
 	read-only
 EOF
+
+				#####
+				if [ "$installdevice" != "/dev/sda" ]; then
+					if [ "$installdevice" != "/dev/sdb" ]; then
+						real_device=`echo $installdevice | cut -c6-8`
+						sed -i "s/$real_device/sdb/g" /mnt/efi/EFI/$efilabel/elilo.conf
+					fi
+				fi
+				#####
+				
 				if [ -f /mnt/install/boot/initrd.gz ]; then
-					echo "  initrd=initrd.gz" >> /mnt/efi/EFI/$efilabel/elilo.conf
+					echo "  initrd=/boot/initrd.gz" >> /mnt/efi/EFI/$efilabel/elilo.conf
 					cp /mnt/install/boot/initrd.gz /mnt/efi/EFI/$efilabel/
 				fi
+				
 				umount /mnt/efi
 				rmdir /mnt/efi
 				efibootmgr -q -c -d $installdevice -p $efipartnum -l "\\EFI\\$efilabel\\elilo.efi" -L "$SLACKEL_FLAVOR ($systempart)"
 			fi
+			
+			# Add the EFI System Partition to /etc/fstab:
+			mkdir -p /mnt/install/boot/efi
+			echo "$efipartition /boot/efi vfat defaults 1 0 " >> /mnt/install/etc/fstab
+			if [ "$installdevice" != "/dev/sda" ]; then
+				mkdir -p /mnt/efi
+				mount $efipartition /mnt/efi
+				mkdir -p /mnt/efi/EFI/BOOT
+				cp /mnt/efi/EFI/$efilabel/* /mnt/efi/EFI/BOOT/
+				mv /mnt/efi/EFI/BOOT/elilo.efi /mnt/efi/EFI/BOOT/bootx64.efi
+				cat > /mnt/efi/EFI/BOOT/elilo.conf << EOF
+timeout=1
+default=$SLACKEL_FLAVOR
+
+image=/EFI/BOOT/vmlinuz
+    label=$SLACKEL_FLAVOR
+    append="root=$systempart ro"
+	read-only
+	initrd=/EFI/BOOT/initrd.gz
+EOF
+
+				if [ "$installdevice" != "/dev/sdb" ]; then
+						real_device=`echo $installdevice | cut -c6-8`
+						sed -i "s/$real_device/sdb/g" /mnt/efi/EFI/BOOT/elilo.conf
+						#sed -i "s/$real_device/sdb/g" /mnt/install/etc/fstab
+				fi
+				umount /mnt/efi
+				rmdir /mnt/efi
+			fi	
+			
+			
 		else #BIOS
 			echo "boot = $installdevice" > /mnt/install/etc/lilo.conf
 			if [ -f /mnt/install/boot/slackel.bmp ]; then
@@ -791,8 +876,9 @@ root = $systempart
 label = $SLACKEL_FLAVOR_LILO
 read-only
 EOF
+			
 			if [ -f /mnt/install/boot/initrd.gz ]; then
-				echo "initrd = /boot/initrd.gz" >> /mnt/install/etc/lilo.conf
+				echo "initrd=/boot/initrd.gz" >> /mnt/install/etc/lilo.conf
 			fi
 			windowspartition=`fdisk -l $installdevice 2>/dev/null | grep "^$installdevice.*\*.*\(NTFS\|FAT32\)" | cut -f1 -d' '`
 			if [ ! -z "$windowspartition" ]; then
@@ -806,6 +892,15 @@ EOF
 			#chroot /mnt/install mount /proc
 			chroot /mnt/install lilo || return $BOOTERROR
 			#chroot /mnt/install umount /proc
+			#####
+			if [ "$installdevice" != "/dev/sda" ]; then
+				if [ "$installdevice" != "/dev/sdb" ]; then
+					real_device=`echo $installdevice | cut -c6-8`
+					sed -i "s/$real_device/sdb/g" /mnt/install/etc/lilo.conf
+				fi
+			fi
+			#####	
+			
 		fi
 	fi
    fi #LiLo end
@@ -820,7 +915,13 @@ EOF
 		#if [ -d /sys/firmware/efi ] && [ ! -z "$efipartnum" ]; then #EFI
 		if [ ! -z "$efipartnum" ] && [ -d $grublibdir/x86_64-efi ]; then
 			efipartition="$installdevice$efipartnum"
-			#modprobe efivars #for efibootmgr; unneded here: done by grub install
+			if [ "$(/bin/ls /sys/firmware/efi/efivars 2> /dev/null | wc -l)" = "0" ]; then
+					echo "Make sure efivarfs is active since we'll need it to"
+					echo "mount efivarfs to efivars"
+					modprobe efivarfs
+					mount -t efivarfs efivarfs /sys/firmware/efi/efivars
+			fi		
+			#======
 			mkdir -p /mnt/efi
 			mount $efipartition /mnt/efi
 			if  [ `uname -m` != "x86_64" ] ; then #modprobe efivars fails on 32 bits Slackware
@@ -835,7 +936,17 @@ EOF
 			# Add the EFI System Partition to /etc/fstab:
 			mkdir -p /mnt/install/boot/efi
 			echo "$efipartition /boot/efi vfat defaults 1 0 " >> /mnt/install/etc/fstab
-		else #CSM
+			if [ "$installdevice" != "/dev/sda" ]; then
+				mkdir -p /mnt/efi
+				mount $efipartition /mnt/efi
+				mkdir -p /mnt/efi/EFI/BOOT
+				cp /mnt/efi/EFI/slackel/grubx64.efi /mnt/efi/EFI/BOOT/bootx64.efi
+				umount /mnt/efi
+				rmdir /mnt/efi
+			fi	
+		fi
+		#else #CSM
+		
 			if echo -e "print\nquit" | parted $installdevice | grep -q ": msdos$" || 
 				gdisk -l $installdevice 2>/dev/null | grep -q " EF02 "; then
 				grub-install --target=i386-pc --boot-directory /mnt/install/boot --recheck --force $installdevice  && grubstatus=0 #grub-bios-setup
@@ -848,11 +959,21 @@ EOF
 					echo "- CSM (legacy) boot: no 'ef02' - BIOS boot partition on $installdevice (GPT)"
 				fi
 			fi
-		fi
+		#fi
 		#for dir in sys proc dev; do mount --bind /$dir /mnt/install/$dir; done
 		chroot /mnt/install grub-mkconfig -o /boot/grub/grub.cfg
 		#for dir in sys proc dev; do umount /mnt/install/$dir; done
 	fi
+		#####
+		#if [ "$installdevice" != "/dev/sda" ]; then
+		#	if [ "$installdevice" != "/dev/sdb" ]; then
+		#		real_device=`echo $installdevice | cut -c6-8`
+		#		sed -i "s/$real_device/sdb/g" /mnt/install/boot/grub/grub.cfg
+		#		sed -i "s/hd2/hd1/g" /mnt/install/boot/grub/grub.cfg
+		#		sed -i "s/ahci2/ahci1/g" /mnt/install/boot/grub/grub.cfg
+		#	fi
+		#fi
+		#####
    fi # end grub
 	
 	liveuser=$(cat /etc/passwd | grep /bin/bash | grep /home/| cut -d : -f 1)
@@ -884,6 +1005,23 @@ EOF
 		#chroot /mnt/install umount /proc
 	fi
 	
+	if [ "$username" != "" ] && [ "$userpassword" != "" ] && [ "$rootpassword" != "" ]; then 
+		echo ${username}:${userpassword} | chroot /mnt/install ln -sf /home/$username/.gtkrc-2.0 /etc/gtk-2.0/gtkrc 
+		echo ${username}:${userpassword} | chroot /mnt/install ln -sf /home/$username/.config/gtk-3.0/settings.ini /etc/gtk-3.0/settings.ini
+	fi
+	 
+    ##############
+	# set locale
+	if [ "$locale" ]; then
+		sed -i "s/^ *\(export LANG=\).*$/\1$locale/" /mnt/install/etc/profile.d/lang.sh
+	    locale_noutf8=`echo $locale | sed "s/.utf8//"`
+	fi
+	# set keyboard
+	if [ "$keyboard" ]; then
+		chroot /mnt/install /usr/sbin/keyboardsetup -k $keyboard  2>/dev/null
+	fi
+	#########
+	
 	if [ -f /mnt/install/etc/kde/kdm/kdmrc ]; then
 	  sed -i "s/NoPassEnable=.*/NoPassEnable=/g" /mnt/install/etc/kde/kdm/kdmrc
 	  sed -i "s/NoPassUsers=.*/NoPassUsers=/g" /mnt/install/etc/kde/kdm/kdmrc
@@ -891,11 +1029,183 @@ EOF
 	  sed -i "s/AllowNullPasswd=.*/AllowNullPasswd=/g" /mnt/install/etc/kde/kdm/kdmrc
 	  sed -i "s/AutoLoginEnable=.*/AutoLoginEnable=/g" /mnt/install/etc/kde/kdm/kdmrc
 	  sed -i "s/AutoLoginUser=.*/AutoLoginUser=/g" /mnt/install/etc/kde/kdm/kdmrc
-	  locale_noutf8=`cat /etc/kde/kdm/kdmrc | grep Language= | sed 's/\Language=//'`
-	  sed -i "s/\(^\|^#\)Language=.*/Language=$locale_noutf8/" /mnt/install/etc/kde/kdm/kdmrc
+	  if [ "$locale" ]; then
+		locale_noutf8=`echo $locale | sed "s/.utf8//"`
+		sed -i "s/^ *\(export LANG=\).*$/\1$locale/" /mnt/install/etc/profile.d/lang.sh
+	  else  
+		locale_noutf8=`cat /etc/kde/kdm/kdmrc | grep Language= | sed 's/\Language=//'`
+		sed -i "s/\(^\|^#\)Language=.*/Language=$locale_noutf8/" /mnt/install/etc/kde/kdm/kdmrc
+	  fi
+	fi
+
+	if [ -f /mnt/install/etc/lightdm/lightdm.conf ]; then
+	cat > /mnt/install/etc/lightdm/lightdm.conf << EOF
+#
+# General configuration
+#
+# start-default-seat = True to always start one seat if none are defined in the configuration
+# greeter-user = User to run greeter as
+# minimum-display-number = Minimum display number to use for X servers
+# minimum-vt = First VT to run displays on
+# lock-memory = True to prevent memory from being paged to disk
+# user-authority-in-system-dir = True if session authority should be in the system location
+# guest-account-script = Script to be run to setup guest account
+# logind-check-graphical = True to on start seats that are marked as graphical by logind
+# log-directory = Directory to log information to
+# run-directory = Directory to put running state in
+# cache-directory = Directory to cache to
+# sessions-directory = Directory to find sessions
+# remote-sessions-directory = Directory to find remote sessions
+# greeters-directory = Directory to find greeters
+# backup-logs = True to move add a .old suffix to old log files when opening new ones
+# dbus-service = True if LightDM provides a D-Bus service to control it
+#
+[LightDM]
+#start-default-seat=true
+#greeter-user=gdm
+#minimum-display-number=0
+#minimum-vt=7
+#lock-memory=true
+#user-authority-in-system-dir=false
+#guest-account-script=guest-account
+#logind-check-graphical=false
+#log-directory=/var/log/lightdm
+#run-directory=/var/run/lightdm
+#cache-directory=/var/cache/lightdm
+#sessions-directory=/usr/share/lightdm/sessions:/usr/share/xsessions:/usr/share/wayland-sessions
+#remote-sessions-directory=/usr/share/lightdm/remote-sessions
+#greeters-directory=$XDG_DATA_DIRS/lightdm/greeters:$XDG_DATA_DIRS/xgreeters
+#backup-logs=true
+#dbus-service=true
+
+#
+# Seat configuration
+#
+# Seat configuration is matched against the seat name glob in the section, for example:
+# [Seat:*] matches all seats and is applied first.
+# [Seat:seat0] matches the seat named "seat0".
+# [Seat:seat-thin-client*] matches all seats that have names that start with "seat-thin-client".
+#
+# type = Seat type (local, xremote)
+# pam-service = PAM service to use for login
+# pam-autologin-service = PAM service to use for autologin
+# pam-greeter-service = PAM service to use for greeters
+# xserver-command = X server command to run (can also contain arguments e.g. X -special-option)
+# xmir-command = Xmir server command to run (can also contain arguments e.g. Xmir -special-option)
+# xserver-config = Config file to pass to X server
+# xserver-layout = Layout to pass to X server
+# xserver-allow-tcp = True if TCP/IP connections are allowed to this X server
+# xserver-share = True if the X server is shared for both greeter and session
+# xserver-hostname = Hostname of X server (only for type=xremote)
+# xserver-display-number = Display number of X server (only for type=xremote)
+# xdmcp-manager = XDMCP manager to connect to (implies xserver-allow-tcp=true)
+# xdmcp-port = XDMCP UDP/IP port to communicate on
+# xdmcp-key = Authentication key to use for XDM-AUTHENTICATION-1 (stored in keys.conf)
+# greeter-session = Session to load for greeter
+# greeter-hide-users = True to hide the user list
+# greeter-allow-guest = True if the greeter should show a guest login option
+# greeter-show-manual-login = True if the greeter should offer a manual login option
+# greeter-show-remote-login = True if the greeter should offer a remote login option
+# user-session = Session to load for users
+# allow-user-switching = True if allowed to switch users
+# allow-guest = True if guest login is allowed
+# guest-session = Session to load for guests (overrides user-session)
+# session-wrapper = Wrapper script to run session with
+# greeter-wrapper = Wrapper script to run greeter with
+# guest-wrapper = Wrapper script to run guest sessions with
+# display-setup-script = Script to run when starting a greeter session (runs as root)
+# display-stopped-script = Script to run after stopping the display server (runs as root)
+# greeter-setup-script = Script to run when starting a greeter (runs as root)
+# session-setup-script = Script to run when starting a user session (runs as root)
+# session-cleanup-script = Script to run when quitting a user session (runs as root)
+# autologin-guest = True to log in as guest by default
+# autologin-user = User to log in with by default (overrides autologin-guest)
+# autologin-user-timeout = Number of seconds to wait before loading default user
+# autologin-session = Session to load for automatic login (overrides user-session)
+# autologin-in-background = True if autologin session should not be immediately activated
+# exit-on-failure = True if the daemon should exit if this seat fails
+#
+[Seat:*]
+#type=local
+#pam-service=lightdm
+#pam-autologin-service=lightdm-autologin
+#pam-greeter-service=lightdm-greeter
+#xserver-command=X
+#xmir-command=Xmir
+#xserver-config=
+#xserver-layout=
+#xserver-allow-tcp=false
+#xserver-share=true
+#xserver-hostname=
+#xserver-display-number=
+#xdmcp-manager=
+#xdmcp-port=177
+#xdmcp-key=
+#greeter-session=example-gtk-gnome
+#greeter-hide-users=false
+#greeter-allow-guest=true
+#greeter-show-manual-login=false
+#greeter-show-remote-login=true
+#user-session=default
+#allow-user-switching=true
+#allow-guest=true
+#guest-session=
+#session-wrapper=lightdm-session
+#greeter-wrapper=
+#guest-wrapper=
+#display-setup-script=
+#display-stopped-script=
+#greeter-setup-script=
+#session-setup-script=
+#session-cleanup-script=
+#autologin-guest=false
+#autologin-user=
+#autologin-user-timeout=0
+#autologin-in-background=false
+#autologin-session=
+#exit-on-failure=false
+
+#
+# XDMCP Server configuration
+#
+# enabled = True if XDMCP connections should be allowed
+# port = UDP/IP port to listen for connections on
+# listen-address = Host/address to listen for XDMCP connections (use all addresses if not present)
+# key = Authentication key to use for XDM-AUTHENTICATION-1 or blank to not use authentication (stored in keys.conf)
+# hostname = Hostname to report to XDMCP clients (defaults to system hostname if unset)
+#
+# The authentication key is a 56 bit DES key specified in hex as 0xnnnnnnnnnnnnnn.  Alternatively
+# it can be a word and the first 7 characters are used as the key.
+#
+[XDMCPServer]
+#enabled=false
+#port=177
+#listen-address=
+#key=
+#hostname=
+
+#
+# VNC Server configuration
+#
+# enabled = True if VNC connections should be allowed
+# command = Command to run Xvnc server with
+# port = TCP/IP port to listen for connections on
+# listen-address = Host/address to listen for VNC connections (use all addresses if not present)
+# width = Width of display to use
+# height = Height of display to use
+# depth = Color depth of display to use
+#
+[VNCServer]
+#enabled=false
+#command=Xvnc
+#port=5900
+#listen-address=
+#width=1024
+#height=768
+#depth=8
+EOF
 	fi
 
-	
 	if [ -f /mnt/install/etc/gdm/custom.conf ]; then
 	cat > /mnt/install/etc/gdm/custom.conf << EOF
 # GDM Custom Configuration file.
@@ -981,6 +1291,106 @@ EOF
 EOF
 	fi
 	
+	if [ -f /mnt/install/etc/slim.conf ]; then
+	cat > /mnt/install/etc/slim.conf << EOF
+# Path, X server and arguments (if needed)
+# Note: -xauth $authfile is automatically appended
+Slackel_path        /bin:/usr/bin:/usr/local/bin
+Slackel_xserver     /usr/bin/X
+#xserver_arguments   -dpi 75
+
+# Commands for halt, login, etc.
+halt_cmd            /sbin/shutdown -h now
+reboot_cmd          /sbin/shutdown -r now
+console_cmd         /usr/bin/xterm -C -fg white -bg black +sb -T "Console login" -e /bin/sh -c "/bin/cat /etc/issue; exec /bin/login"
+#suspend_cmd        /usr/sbin/suspend
+## slackware suspend command
+suspend_cmd        /usr/sbin/pm-suspend
+
+# Full path to the xauth binary
+xauth_path         /usr/bin/xauth 
+
+# Xauth file for server
+authfile           /var/run/slim.auth
+
+
+# Activate numlock when slim starts. Valid values: on|off
+# numlock             on
+
+# Hide the mouse cursor (note: does not work with some WMs).
+# Valid values: true|false
+# hidecursor          false
+
+# This command is executed after a succesful login.
+# you can place the %session and %theme variables
+# to handle launching of specific commands in .xinitrc
+# depending of chosen session and slim theme
+#
+# NOTE: if your system does not have bash you need
+# to adjust the command according to your preferred shell,
+# i.e. for freebsd use:
+# login_cmd           exec /bin/sh - ~/.xinitrc %session
+login_cmd           exec /bin/bash -login ~/.xinitrc %session
+
+# Commands executed when starting and exiting a session.
+# They can be used for registering a X11 session with
+# sessreg. You can use the %user variable
+#
+# sessionstart_cmd	some command
+# sessionstop_cmd	some command
+
+# Start in daemon mode. Valid values: yes | no
+# Note that this can be overriden by the command line
+# options "-d" and "-nodaemon"
+# daemon	yes
+
+# Available sessions (first one is the Slackel).
+# The current chosen session name is replaced in the login_cmd
+# above, so your login command can handle different sessions.
+# see the xinitrc.sample file shipped with slim sources
+sessions            xfce4,icewm-session,wmaker,blackbox
+
+# Executed when pressing F11 (requires imagemagick)
+screenshot_cmd      import -window root /slim.png
+
+# welcome message. Available variables: %host, %domain
+welcome_msg         Welcome to %host
+
+# Session message. Prepended to the session name when pressing F1
+# session_msg         Session: 
+
+# shutdown / reboot messages
+shutdown_msg       The system is halting...
+reboot_msg         The system is rebooting...
+
+# Slackel user, leave blank or remove this line
+# for avoid pre-loading the username.
+#Slackel_user        simone
+
+# Focus the password field on start when Slackel_user is set
+# Set to "yes" to enable this feature
+#focus_password      no
+
+# Automatically login the Slackel user (without entering
+# the password. Set to "yes" to enable this feature
+#auto_login          no
+
+
+# current theme, use comma separated list to specify a set to 
+# randomly choose from
+current_theme       Slackel
+
+# Lock file
+lockfile            /var/run/slim.lock
+
+# Log file
+logfile             /var/log/slim.log
+
+EOF
+
+	chmod 755 /mnt/install/usr/bin/slim
+fi
+
 	echo "Removing installer"
 	#chroot /mnt/install rm -f /home/one/Desktop/slackel-live-installer.desktop
 	chroot /mnt/install rm -f /home/one/Desktop/sli*.desktop
@@ -988,6 +1398,9 @@ EOF
 	#chroot /mnt/install spkg -d slackel-live-installer
 	chroot /mnt/install /sbin/spkg -d sli
 	
+	#chroot /mnt/install
+	
+	
 	# Run various slackware install routines
 	#echo "Run various slackware install routines"
 	
@@ -1014,12 +1427,161 @@ EOF
 	chmod 644 /mnt/install/etc/HOSTNAME  
 		
 	# Use any available swap device:
-    for SWAPD in $(blkid |grep TYPE="\"swap\"" |cut -d: -f1) ; do
+    for SWAPD in $(blkid | grep $installdevice |grep TYPE="\"swap\"" |cut -d: -f1) ; do
       echo "Enabling swapping to '$SWAPD'"
       echo "$SWAPD  swap  swap defaults  0  0" >> /mnt/install/etc/fstab
     done
 
-	for dir in sys proc dev; do umount /mnt/install/$dir; done
+	  #####
+		#if [ "$installdevice" != "/dev/sda" ]; then
+		#	if [ "$installdevice" != "/dev/sdb" ]; then
+		#		real_device=`echo $installdevice | cut -c6-8`
+		#		sed -i "s/$real_device/sdb/g" /mnt/install/etc/fstab
+		#		sed -i "s/$real_device/sdb/g" /mnt/install/etc/mtab
+		#	fi
+		#fi
+	   #####
+	lsblk -l -o uuid,type,name|grep part| \
+	sed "s, *\([^ ]*\) *[^ ]*  *\([^ ]*\).*,s;/dev/\2;UUID=\1;," > /tmp/part_list
+    if [ ! -f /mnt/install/etc/fstab ]; then
+		echo "No /mnt/install/etc/fstab found. Something should be wrong."
+		echo "Bye."
+	else
+		echo "Updating /mnt/install/etc/fstab paritions with UUID"
+	fi
+	if [ ! -f /mnt/install/etc/fstab.orig ]; then
+		cp /mnt/install/etc/fstab /mnt/install/etc/fstab.orig
+	fi
+	sed -f /tmp/part_list /mnt/install/etc/fstab >dummy
+	mv dummy /mnt/install/etc/fstab
+    ###############
+    # setup services
+    echo "setup services"
+    if [ -r /mnt/install/etc/rc.d/rc.alsa ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.alsa
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.atalk ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.atalk
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.bind ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.bind
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.bluetooth ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.bluetooth
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.cups ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.cups
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.cgmanager ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.cgmanager
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.cgproxy ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.cgproxy
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.dnsmasq ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.dnsmasq
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.fuse ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.fuse
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.hald ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.hald
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.hplip ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.hplip
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.httpd ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.httpd
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.inetd ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.inetd
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.ip_forward ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.ip_forward
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.lprng ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.lprng
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.messagebus ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.messagebus
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.mysqld ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.mysqld
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.networkmanager ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.networkmanager
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.ntpd ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.ntpd
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.pcmcia ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.pcmcia
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.pulseaudio ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.pulseaudio
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.rpc ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.rpc
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.samba ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.samba
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.saslauthd ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.saslauthd
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.sendmail ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.sendmail
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.serial ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.serial
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.snmpd ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.snmpd
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.syslog ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.syslog
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.sshd ]; then
+		chmod -x /mnt/install/etc/rc.d/rc.sshd
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.wicd ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.wicd
+	fi
+
+	if [ -r /mnt/install/etc/rc.d/rc.wireless ]; then
+		chmod +x /mnt/install/etc/rc.d/rc.wireless
+	fi
+    ################### 
+	for dir in sys proc dev tmp; do umount /mnt/install/$dir; done
 
 	if [ "$home_dir" != "" ] && [ "$home_dir" != "$systempart" ]; then
 		echo "umount /mnt/instal/home"
@@ -1030,6 +1592,7 @@ EOF
 
 	echo "remove /mnt/install"
 	rmdir /mnt/install
+	
 	echo "end installation"
 	return 0
 }
@@ -1155,7 +1718,13 @@ case $action in
 			#moduleslist="squashfs:fuse:loop:xhci-pci:ehci-pci:usb-storage:ext3:isofs"
 			#moduleslist="squashfs:fuse:loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:usb-storage:hid:usbhid:hid-generic:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:jbd:mbcache:ext3:ext4:isofs:fat:nls_cp437:nls_iso8859-1:msdos:vfat"
 			#moduleslist="squashfs:fuse:loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:isofs:nls_cp437:nls_iso8859-1"
-			moduleslist="squashfs:overlay:loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:ext3:ext4:isofs:nls_cp437:nls_iso8859-1"
+			#moduleslist="squashfs:overlay:loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:ext3:ext4:isofs:nls_cp437:nls_iso8859-1"
+		    
+		    #moduleslist="squashfs:overlay:loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:isofs:nls_cp437:nls_iso8859-1"
+			moduleslist="squashfs:overlay:loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:mmc-core:mmc-block:sdhci:sdhci-pci:sdhci-acpi:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-apple:hid-asus:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:isofs:crc32c-intel:fuse:nls_cp437:nls_iso8859-1"
+			
+			#moduleslist="squashfs:overlay:loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:mmc-core:mmc-block:sdhci:sdhci-pci:sdhci-acpi:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-apple:hid-asus:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:isofs:crc32c-intel:fuse"
+			#moduleslist="squashfs:overlay:isofs:vfat:ext4:loop:xhci-pci:ehci-pci:usb-storage:usbhid:nls_cp437:nls_iso8859-1"
 		fi
 		init_live $rootdirectory $livedirectory $moduleslist
 	else
@@ -1234,6 +1803,8 @@ case $action in
 	format_home=${10}
 	SYSINSTALLFS=${11}
 	home_dir=${12}
+	locale=${13}
+	keyboard=${14}
 	
 	if [ -d "$rootdirectory" ] && [ -b "$systempart" ]; then
 		systemsize=`du -s -m $rootdirectory | sed 's/\t.*//'`
@@ -1249,11 +1820,11 @@ case $action in
 		  if [ "$home_dir" == "" ]; then
 			SYSINSTALLFS="ext4"
 		  fi
-			install_system $rootdirectory $systempart $loadersetup $rootpassword $username $userpassword $installation_mode $bootloader $format_home $SYSINSTALLFS $home_dir
+			install_system $rootdirectory $systempart $loadersetup $rootpassword $username $userpassword $installation_mode $bootloader $format_home $SYSINSTALLFS $home_dir $locale $keyboard
 			exit $!
 		fi
 	else
-		echo "`basename $0` --install root_dir device [-auto|-expert] rootpassword username userpassword installation_mode bootloader format_home SYSINSTALLFS home_dir"
+		echo "`basename $0` --install root_dir device [-auto|-z] rootpassword username userpassword installation_mode bootloader format_home SYSINSTALLFS home_dir locale keyboard"
 		exit $CMDERROR
 	fi
 	;;
